package VMOMI::ClusterProfileServiceType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
